/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { Locator, WebDriver, Capabilities, WebElement, WebElementPromise, FileDetector, Session, Actions, WebElementCondition, Condition, Options, Navigation, TargetLocator } from 'selenium-webdriver';
import { Command, Executor } from 'selenium-webdriver/lib/command';
import { NetworkConnectionParam } from './mobileextension';
interface INativeWaitAndGet {
    /**
   * wait until element by accessibility id exists or timeout
   */
    getByNativeAccessibilityId(id: string, timeout?: number, message?: string): WebElementPromise;
    /**
   * wait until element by name exists or timeout
   */
    getByNativeName(name: string, timeout?: number, message?: string): WebElementPromise;
    /**
   * wait until element by id exists or timeout
   */
    getByNativeId(id: string, timeout?: number, message?: string): WebElementPromise;
    /**
   * wait until element by class name exists or timeout
   */
    getByNativeclassName(className: string, timeout?: number, message?: string): WebElementPromise;
}
interface IWaitAndGet extends INativeWaitAndGet {
    /**
     * wait until element by locator exists or timeout
     */
    getBy(locator: Locator, timeout?: number, message?: string): WebElementPromise;
}
/**
 * @see https://github.com/SeleniumHQ/mobile-spec/blob/master/spec-draft.md
 */
export interface IMobileJSONWireExtension {
    /**
     * A workaround before WebDriver supports Mobile JSONWire
     */
    enableMobileJSONWire(): void;
    getNetworkCondition(): Promise<NetworkConnectionParam>;
    setNetworkCondition(params: NetworkConnectionParam): Promise<NetworkConnectionParam>;
}
export interface IWebDriver2 extends IWaitAndGet, IMobileJSONWireExtension {
    attach(webDriver: WebDriver): void;
    detach(): void;
    start(): Promise<void>;
    stop(): Promise<void>;
    restart(): Promise<void>;
    isActive(): Promise<boolean>;
    seleniumDriver(): WebDriver;
    lastError(): any;
}
export declare class WebDriver2 implements IWebDriver2 {
    enableMobileJSONWire(): void;
    getNetworkCondition(): Promise<NetworkConnectionParam>;
    setNetworkCondition(params: NetworkConnectionParam): Promise<NetworkConnectionParam>;
    /**
    *   @see WebDriver.wait
    */
    wait(condition: WebElementCondition, opt_timeout?: number | undefined, opt_message?: string | undefined): WebElementPromise;
    /**
  *   @see WebDriver.wait
  */
    wait2<T>(condition: Function | PromiseLike<T> | Condition<T> | ((driver: WebDriver) => T | PromiseLike<T>), opt_timeout?: number | undefined, opt_message?: string | undefined): Promise<T>;
    /**
  *   @see WebDriver.sleep
  */
    sleep(ms: number): Promise<void>;
    /**
  *   @see WebDriver.execute
  */
    execute<T>(command: Command, description?: string | undefined): Promise<T>;
    /**
  *   @see WebDriver.setFileDetector
  */
    setFileDetector(detector: FileDetector): void;
    /**
  *   @see WebDriver.getExecutor
  */
    getExecutor(): Executor;
    /**
  *   @see WebDriver.getSession
  */
    getSession(): Promise<Session>;
    /**
  *   @see WebDriver.getCapabilities
  */
    getCapabilities(): Promise<Capabilities>;
    /**
  *   @see WebDriver.quit
  */
    quit(): Promise<void>;
    /**
  *   @see WebDriver.actions
  */
    actions(options?: {
        async: boolean;
        bridge: boolean;
    } | {
        async: boolean;
    } | {
        bridge: boolean;
    } | undefined): Actions;
    /**
  *   @see WebDriver.executeScript
  */
    executeScript<T>(script: string | Function, ...var_args: any[]): Promise<T>;
    /**
  *   @see WebDriver.executeAsyncScript
  */
    executeAsyncScript<T>(script: string | Function, ...var_args: any[]): Promise<T>;
    /**
  *   @see WebDriver.getWindowHandle
  */
    getWindowHandle(): Promise<string>;
    /**
    *   @see WebDriver.getAllWindowHandles
    */
    getAllWindowHandles(): Promise<string[]>;
    /**
    *   @see WebDriver.getPageSource
    */
    getPageSource(): Promise<string>;
    /**
    *   @see WebDriver.close
    */
    close(): Promise<void>;
    /**
    *   @see WebDriver.get
    */
    get(url: string): Promise<void>;
    /**
    *   @see WebDriver.getCurrentUrl
    */
    getCurrentUrl(): Promise<string>;
    /**
    *   @see WebDriver.getTitle
    */
    getTitle(): Promise<string>;
    /**
    *   @see WebDriver.findElement
    */
    findElement(locator: Locator): WebElementPromise;
    /**
    *   @see WebDriver.findElements
    */
    findElements(locator: Locator): Promise<WebElement[]>;
    /**
    *   @see WebDriver.takeScreenshot
    */
    takeScreenshot(): Promise<string>;
    /**
    *   @see WebDriver.manage
    */
    manage(): Options;
    /**
    *   @see WebDriver.navigate
    */
    navigate(): Navigation;
    /**
    *   @see WebDriver.switchTo
    */
    switchTo(): TargetLocator;
    getBy(locator: Locator, timeout?: number, message?: string | undefined): WebElementPromise;
    getByNativeAccessibilityId(id: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    getByNativeName(name: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    getByNativeId(id: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    getByNativeclassName(className: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    seleniumDriver(): WebDriver;
    lastError(): any;
    attach(webDriver: WebDriver): void;
    detach(): void;
    start(): Promise<void>;
    stop(): Promise<void>;
    restart(): Promise<void>;
    private _restart;
    private capabilities_?;
    private error_?;
    private url_;
    private webDriver?;
    constructor(capabilities?: Capabilities | {}, url?: string);
    isActive(): Promise<boolean>;
}
export declare function createWebDriver2(capabilities?: Capabilities | {}, url?: string): WebDriver2;
export {};
